@@ -51,9 +51,10 @@ int            gdm_wait_on_and_disown_pid (int pid,
 int            gdm_signal_pid            (int pid,
                                           int signal);
 
-gboolean       gdm_find_display_session_for_uid (const uid_t uid,
-                                                 char      **out_session_id,
-                                                 GError    **error);
+gboolean       gdm_find_display_session (GPid        pid,
+                                         const uid_t uid,
+                                         char      **out_session_id,
+                                         GError    **error);
 
 gboolean       gdm_get_pwent_for_name    (const char     *name,
                                           struct passwd **pwentp);
